package org.jvending.provisioning.adapter;

import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.ServletException;
import javax.provisioning.adapter.AdapterContext;
import javax.provisioning.adapter.AdapterException;
import javax.provisioning.*;
import java.io.IOException;
import java.io.OutputStream;
import java.util.logging.Logger;

public class GenericAdapterServlet extends HttpServlet {

    private static Logger logger = Logger.getLogger("GenericAdapterServlet");

    public void service(HttpServletRequest request, HttpServletResponse response) throws IOException, ServletException {
        String fulfillmentId = request.getParameter("fid");
        logger.info("Fulfillment ID = " + fulfillmentId);

        AdapterContext adapterContext = (AdapterContext)
                this.getServletContext().getAttribute("javax.provisioning.ProvisioningContext");
        DeliveryContext deliveryContext = adapterContext.getDeliveryContext(request);
        DeliveryComponent deliveryComponent = adapterContext.getDeliveryComponent();

        FulfillmentTask fulfillmentTask = null;
        try {
            fulfillmentTask = adapterContext.getFulfillmentTask(fulfillmentId, deliveryContext, "generic");
        } catch (AdapterException e) {
            e.printStackTrace();
            throw new IOException("Could not get fulfillment task");
        }

        Deliverable deliverable = null;
        try {
            BundleDescriptor bundleDescriptor = fulfillmentTask.getBundleDescriptor();
            if(bundleDescriptor == null)
                throw new ProvisioningException("JV: Could not find the BundleDescriptor for this FulfillmentTask");
            deliverable = deliveryComponent.getContentFile(bundleDescriptor.getContentFile(),
                    fulfillmentTask);
        } catch (ProvisioningException e) {
            throw new IOException(e.getMessage());
        }

        OutputStream os = response.getOutputStream();
        response.setContentType(deliverable.getMimeType());
        try {
            deliverable.writeContents(os);
        } catch (IOException e) {
            DeliveryEvent event = new DeliveryEvent(deliveryContext, fulfillmentTask.getAdapterName(),
                    DeliveryEvent.FAILED, fulfillmentId, 0, "Delivery Failed");
            try {
                deliveryComponent.handleDeliveryEvent(event);
            } catch (ProvisioningException e1) {
                e1.printStackTrace();
            }
            throw new IOException(e.getMessage());
        }
        os.close();

        DeliveryEvent event = new DeliveryEvent(deliveryContext, fulfillmentTask.getAdapterName(),
                DeliveryEvent.COMPLETE, fulfillmentId, 0, "Delivery Complete");

        try {
            deliveryComponent.handleDeliveryEvent(event);
        } catch (ProvisioningException e) {
            e.printStackTrace();
        }
    }

}
