package org.jvending.provisioning.config;

import org.jvending.registry.Repository;
import org.jvending.registry.RepositoryRegistry;
import org.jvending.provisioning.config.stockinghandlers.StockingHandlerType;
import org.jvending.provisioning.config.stockinghandlers.StockingFiltersType;
import org.jvending.provisioning.config.stockinghandlers.DescriptorHandlersType;
import org.jvending.provisioning.config.stockinghandlers.StockingPolicyType;

import java.io.InputStream;
import java.io.IOException;
import java.util.Hashtable;
import java.util.ArrayList;
import java.util.List;

public final class StockingHandlerRepository implements Repository {

    private StockingHandlerType stockingHandlerType;

    private List stockingFilterNames;

    private List descriptorHandlers;

    private List initParams;

    private StockingPolicyType stockingPolicy;

    private String dataSinkName;

    StockingHandlerRepository(StockingHandlerType stockingHandlerType) {
        this.stockingHandlerType = stockingHandlerType;

        StockingFiltersType stockingFiltersType = stockingHandlerType.getStockingFilters();
        if(stockingFiltersType != null) stockingFilterNames = stockingFiltersType.getStockingFilter();

        initParams = stockingHandlerType.getInitParam();

        stockingPolicy = stockingHandlerType.getStockingPolicy();

        DescriptorHandlersType descriptorHandlersType = stockingHandlerType.getDescriptorHandlers();
        descriptorHandlers = (descriptorHandlersType != null) ? descriptorHandlersType.getDescriptorHandler():
                                                                new ArrayList();

        dataSinkName = stockingHandlerType.getDataSink();
    }

    public List getStockingFilterNames() {
        return stockingFilterNames;
    }

    public List getDescriptorHandlers() {
        return descriptorHandlers;
    }

    public String getDataSinkName() {
        return dataSinkName;
    }

    public StockingPolicyType getStockingPolicyType() {
        return stockingPolicy;
    }

    public List getInitParams() {
        return initParams;
    }

    public void load(InputStream inputStream, Hashtable properties) throws IOException { }

    public void setRepositoryRegistry(RepositoryRegistry repositoryRegistry) {
        //don't need this
    }
}
