package org.jvending.provisioning.portal;

import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.provisioning.*;
import java.io.IOException;
import java.net.URI;
import java.net.URISyntaxException;
import java.util.logging.Logger;

public class AdapterControllerServlet extends HttpServlet {

    private static Logger logger = Logger.getLogger("AdapterControllerServlet");

    protected void service(HttpServletRequest request,
                           HttpServletResponse response) throws javax.servlet.ServletException, java.io.IOException {

        String bundleId = request.getParameter("bundleId");

        ProvisioningContext provisioningContext = (ProvisioningContext)
                this.getServletContext().getAttribute("javax.provisioning.ProvisioningContext");
        BundleDescriptor bundleDescriptor = provisioningContext.getBundleRepository().getBundleByID(bundleId);
        DeliveryContext deliveryContext = provisioningContext.getDeliveryContext(request);

       /* This is where you can do authentication/authorization of the user
        * String userId = deliveryContext.getUser();
        * authenticationModule.authenticate(userId);
        * ....
        */
        FulfillmentTask fulfillmentTask = null;

        try {
            fulfillmentTask = provisioningContext.createFulfillmentTask(bundleDescriptor, deliveryContext);
            logger.info("Create task = " + fulfillmentTask.toString());
        } catch (ProvisioningException e) {
            e.printStackTrace();
            throw new IOException("JV: Could not create a FulfillmentTask: Bundle ID = " + bundleId);
        }

        /*IF WAP PUSH - use this fulfillmentTask.getDeliveryURI(); for the delivery URL
         * This may be consider WAP Push if user-agent is incapable of supporting the content.
         * Use the network id (MSISDN) for the recipient
         */

        try {
            URI uri = new URI(fulfillmentTask.getDeliveryURI());
            logger.info("Sending to URI = " + uri.toString());
            if(uri.isAbsolute()) response.sendRedirect(uri.toString());
            else request.getRequestDispatcher(uri.toString()).forward(request, response);
        } catch (ProvisioningException e) {
            e.printStackTrace();
        } catch(URISyntaxException e) {
            e.printStackTrace();
         }
    }


}
