/*
 *  JVending
 *  Copyright (C) 2004  Shane Isbell
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

package org.jvending.provisioning.stocking;

import java.io.Serializable;
import java.util.EventObject;

/**
 * Used for notification of events that occur while stocking a PAR file.
 *
 * @author Shane Isbell
 * @since 2.0.0
 */

public class StockingEvent extends EventObject implements Serializable {

    public static int COMPLETE = 0;

    public static int CONFIRMED = 1;

    public static int REMOVED = 2;

    public static int FAILED = 3;

    public static int OTHER = 5;

    private int eventCode;

    private String message;

    private ProviderContext providerContext;

    private String filterID;

    public StockingEvent(ProviderContext providerContext, String filterID, int eventCode, String message) {
        super(providerContext);
        this.filterID = filterID;
        this.eventCode = eventCode;
        this.message = message;
        this.providerContext = providerContext;
    }

    public int getEventCode() {
        return this.eventCode;
    }

    public String getMessage() {
        return this.message;
    }

    public ProviderContext getProviderContext() {
        return providerContext;
    }

    public String getFilterID() {
        return filterID;
    }
}
