package org.jvending.provisioning.stocking.filter;

import junit.framework.TestCase;
import org.jvending.provisioning.stocking.par.ProvisioningArchive;
import org.jvending.provisioning.stocking.par.ClientBundleType;
import org.easymock.MockControl;

import javax.xml.bind.JAXBContext;
import javax.xml.bind.JAXBException;
import javax.xml.bind.Unmarshaller;

import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.util.List;
import java.util.Iterator;

public class FormatFilterTest extends TestCase {

    private static String baseDir = System.getProperty("basedir");

    private ProvisioningArchive archive;

    public void setUp() {
        FileInputStream fis = null;
        try {
            fis = new FileInputStream(baseDir + "/src/test/resources/provisioning.xml");
        } catch (FileNotFoundException e) {
            fail("Could not find provisioning.xml file");
        }
        try {
            JAXBContext jaxbContext = JAXBContext.newInstance("org.jvending.provisioning.stocking.par");
            Unmarshaller unmarshaller = jaxbContext.createUnmarshaller();
            unmarshaller.setValidating(true);
            archive = (ProvisioningArchive) unmarshaller.unmarshal(fis);
        } catch (JAXBException e) {
            e.printStackTrace();
            fail("Parsing exception for provisioning descriptor");
        }
    }

    public void testWhiteSpaceRemoval() {
        MockControl controlFilterTask = MockControl.createControl(FilterTask.class);
        FilterTask filterTask = (FilterTask) controlFilterTask.getMock();

        filterTask.getProvisioningArchive();
        controlFilterTask.setReturnValue(archive);

        controlFilterTask.replay();

        new FormatFilter().doFilter(filterTask);
        List clientBundleTypes = archive.getClientBundle();
        for (Iterator i = clientBundleTypes.iterator(); i.hasNext();) {
            ClientBundleType clientBundleType = (ClientBundleType) i.next();
            String version = clientBundleType.getVersion();
            if (version != null && !version.equals(version.trim()))
                fail("Versions do not match");
        }
    }
}
